==> xiaothink-1.0.1-py3-none-any.whl: xiaothink/llm/inference/test_formal.py <==
'''
try:import test
except ImportError:
    import xiaothink.llm.inference.test as test
'''
import xiaothink.llm.inference.test as test
#form



class QianyanModel:
    def __init__(self,ckpt_dir=r'E:\小思框架\论文\ganskchat\ckpt_test_40_2_3_1_formal_open',
               MT=40.231,
                 vocab=r'E:\小思框架\论文\ganskchat\vocab_lx3.txt'):
        self.model,self.d=test.load(ckpt_dir=ckpt_dir, model_type=MT, vocab=vocab)
        self.his=''
    #moe lyric:0.72
    def chat_SingleTurn(self,t,temp=0.76,form=0,ontime=True):#0.85
        
        if form==0:
            inp=f'{{"instruction": "{t}", "input": "", "output": "'
            stopc=['"}\r\n',
                   '"}\n\r',
                   '"}\n',
                   '", "input"',
                   '", "i',
                   '"}'
                   ]
        else:
            print('Err')
            
            return '-1: form error'
        funct=None
        if ontime:
            funct=lambda a:print(a,end='',flush=True)

        #print(funct)
        re=test.generate_texts_untilstr_loop(self.model, self.d, inp,num_generate=150,
                                 every=funct,
                                 temperature=temp,#0.8
                                stop_c=stopc
                                    #q=[0.6,0.4]
                                    )
        self.model.reset_states()
        return re
    def chat(self,text,temp=0.78,max_len=150,form=0,ontime=True):
        if self.his!='':
            self.his+='\\nHuman: '+text.replace('\n','\\n')+'\\nAssistant:'
        else:
           self.his+='Human: '+text.replace('\n','\\n')+'\\nAssistant:'
        #print('his',self.his)
        t=self.his
        if form==0:
            inp=f'{{"instruction": "{t}", "input": "", "output": "'
            stopc=['"}\r\n',
                   '"}\n\r',
                   '"}\n',
                   '", "input"',
                   '", "i',
                   '"}',
                   '\\nHuman:',
                   ]
        else:
            print('Err')
            return '-1: form error'
        funct=None
        if ontime:
            funct=lambda a:print(a,end='',flush=True)
            print('\n【实时输出】')
        #print(funct)
        re=test.generate_texts_untilstr_loop(self.model, self.d, inp,num_generate=max_len,
                                 every=funct,
                                 temperature=temp,#0.8
                                stop_c=stopc
                                    #q=[0.6,0.4]
                                    )
        self.his+=re
        return re

    def clean_his(self):
        self.his=''

    def write(self,t,temp=0.85,max_len=150,form=0,ontime=True,onfunc=None):#0.62

        
        if ontime:
            funct=onfunc#lambda a:print(a,end='',flush=True)

        #print(funct)
        re=test.generate_texts_loop(self.model, self.d, t,num_generate=max_len,
                                 every=funct,
                                 temperature=temp,#0.8
                                    #q=[0.6,0.4]
                                    )
        return re
    
#你要写歌词，用神采为题
#用卫星图像显示中国向南海岛屿派歼11战机,已降落在永兴 岛,美菲将讨论中国“挑衅”行为。为题写报道
        
if __name__=='__main__':
    model=QianyanModel()
    while True:
        inp=input('【问】：')
        if inp =='[CLEAN]':
            print('【清空上下文】\n\n')
            model.clean_his()
            continue
        re=model.chat_SingleTurn(inp)#model.chat(inp,temp=0.55)#
        print('\n【答】：',re,'\n')

==> xiaothink-1.0.2-py3-none-any.whl: xiaothink/llm/inference/test_formal.py <==
'''
try:import test
except ImportError:
    import xiaothink.llm.inference.test as test
'''
import xiaothink.llm.inference.test as test
#form



class QianyanModel:
    def __init__(self,ckpt_dir=r'E:\小思框架\论文\ganskchat\ckpt_test_40_2_3_1_formal_open',
               MT=40.231,
                 vocab=r'E:\小思框架\论文\ganskchat\vocab_lx3.txt'):
        self.model,self.d=test.load(ckpt_dir=ckpt_dir, model_type=MT, vocab=vocab)
        self.his=''
    #moe lyric:0.72
    def chat_SingleTurn(self,t,temp=0.76,form=0,ontime=True,stop=None):#0.85
        
        if form==0:
            inp=f'{{"instruction": "{t}", "input": "", "output": "'
            stopc=['"}\r\n',
                   '"}\n\r',
                   '"}\n',
                   '", "input"',
                   '", "i',
                   '"}'
                   ]
        else:
            print('Err')
            
            return '-1: form error'
        funct=None
        if ontime:
            funct=lambda a:print(a,end='',flush=True)
        if stop:
            stopc.append(stop)
        #print(funct)
        re=test.generate_texts_untilstr_loop(self.model, self.d, inp,num_generate=150,
                                 every=funct,
                                 temperature=temp,#0.8
                                stop_c=stopc
                                    #q=[0.6,0.4]
                                    )
        self.model.reset_states()
        return re
    def chat(self,text,temp=0.78,max_len=150,form=0,ontime=True):
        if self.his!='':
            self.his+='\\nHuman: '+text.replace('\n','\\n')+'\\nAssistant:'
        else:
           self.his+='Human: '+text.replace('\n','\\n')+'\\nAssistant:'
        #print('his',self.his)
        t=self.his
        if form==0:
            inp=f'{{"instruction": "{t}", "input": "", "output": "'
            stopc=['"}\r\n',
                   '"}\n\r',
                   '"}\n',
                   '", "input"',
                   '", "i',
                   '"}',
                   '\\nHuman:',
                   ]
        else:
            print('Err')
            return '-1: form error'
        funct=None
        if ontime:
            funct=lambda a:print(a,end='',flush=True)
            print('\n【实时输出】')
        #print(funct)
        re=test.generate_texts_untilstr_loop(self.model, self.d, inp,num_generate=max_len,
                                 every=funct,
                                 temperature=temp,#0.8
                                stop_c=stopc
                                    #q=[0.6,0.4]
                                    )
        self.his+=re
        return re

    def clean_his(self):
        self.his=''

    def write(self,t,temp=0.85,max_len=150,form=0,ontime=True,onfunc=None):#0.62

        
        if ontime:
            funct=onfunc#lambda a:print(a,end='',flush=True)

        #print(funct)
        re=test.generate_texts_loop(self.model, self.d, t,num_generate=max_len,
                                 every=funct,
                                 temperature=temp,#0.8
                                    #q=[0.6,0.4]
                                    )
        return re
    
#你要写歌词，用神采为题
#用卫星图像显示中国向南海岛屿派歼11战机,已降落在永兴 岛,美菲将讨论中国“挑衅”行为。为题写报道
        
if __name__=='__main__':
    model=QianyanModel()
    while True:
        inp=input('【问】：')
        if inp =='[CLEAN]':
            print('【清空上下文】\n\n')
            model.clean_his()
            continue
        re=model.chat_SingleTurn(inp)#model.chat(inp,temp=0.55)#
        print('\n【答】：',re,'\n')
